
Atom-centered Persistent Homology
.............................................

The idea is to compute persistent-homology described descriptors for local environments.

.. figure:: ../../figures/atomcentredph.png
   :align: center
   :scale: 100%
   :alt: persistent-homology-persistent-homology. Figure taken from the original article.

.. featurizer::  AtomCenteredPH
    :id: AtomCenteredPH
    :considers_geometry: True
    :considers_structure_graph: False
    :encodes_chemistry: optionally
    :scope: global
    :scalar: False

    Initially described in [Jiang2021]_.
